<xsl:stylesheet xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:dri="http://www.driver-repository.eu/namespace/dri"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:edm="http://www.europeana.eu/schemas/edm/"
    xmlns:oai="http://www.openarchives.org/OAI/2.0/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    xmlns:ore="http://www.openarchives.org/ore/terms/" xmlns:date="http://exslt.org/dates-and-times"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:dcterms="http://purl.org/dc/terms/"
    extension-element-prefixes="date" version="1.1">
    <xsl:output encoding="UTF-8" indent="yes" method="xml" version="1.1"/>
    <xsl:variable name="smallcase" select="'abcdefghijklmnopqrstuvwxyz'"/>
    <xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
    <!-- repoId is set at run time to the identifier of the repository, assigned by the aggregator, whose record is to be transformed. -->
    <xsl:param name="repoId">
        <xsl:value-of select="string('HA')"/>
    </xsl:param>
    <!-- objId is set at runtime to the identifier of the current HOPE record to transform. -->
    <xsl:param name="objId"/>
    <!-- 
        This is a template for the generation of the identifier for the EDM Aggregation entity: we extract the last 2 tokens.
        Example: input = http://hdl.handle.org/12345/ABCDE, output = 12345/ABCDE
        This is because we generate 1 ProvidedCHO and 1 Aggregation for each HOPE descriptive unit, but we cannot use the same identifier for both EDM entities.
    -->
    <xsl:template name="getAggrID">
        <xsl:param name="input"/>
        <xsl:param name="lastInput"/>
        <xsl:choose>
            <xsl:when test="contains($input, '/')">
                <xsl:call-template name="getAggrID">
                    <xsl:with-param name="input" select="substring-after($input, '/')"/>
                    <xsl:with-param name="lastInput" select="$input"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$lastInput"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- Entry Points: one Hope entity can be either a descriptiveUnit  or a digitalResource -->
    <xsl:template match="/">
        <record>
            <header>
                <dri:repositoryId>
                    <xsl:value-of select="$repoId"/>
                </dri:repositoryId>
                <dri:objIdentifier>
                    <xsl:value-of select="$objId"/>
                </dri:objIdentifier>
                <dri:dateOfCollection>
                    <xsl:value-of select="date:date-time()"/>
                </dri:dateOfCollection>
                <identifier>
                    <xsl:value-of select="$objId"/>
                </identifier>
                <setSpec/>
            </header>
            <metadata>
                <rdf:RDF>
                    <xsl:apply-templates select="//hopeEntity/*"/>
                </rdf:RDF>
            </metadata>
        </record>
    </xsl:template>
    <xsl:template match="*|@*|text()"/>
    <xsl:template match="//hopeEntity/descriptiveUnit">
        <xsl:call-template name="descriptiveUnitTemplate"/>
    </xsl:template>
    <xsl:template match="//hopeEntity/digitalResource">
        <xsl:call-template name="digitalResourceTemplate"/>
    </xsl:template>
    <!--end of entry points -->

    <!-- 
        Helper template for the generation of fields: it adds an xml:lang attribute only if the source field has a non blank language.
        This was asked by the Europeana Ingestion Team: they do not want to have empty xml:lang attributes.
        Example: <dc:description xml:lang=""> is refused, <dc:description> or <dc:description xml:lang="eng"> are fine.
    -->
    <xsl:template name="langField">
        <xsl:param name="fieldName"/>
        <xsl:param name="fieldValue"/>
        <xsl:param name="language"/>
        <xsl:choose>
            <xsl:when test="normalize-space($language) != ''">
                <xsl:element name="{$fieldName}">

                    <xsl:attribute name="xml:lang">
                        <xsl:value-of select="$language"/>
                    </xsl:attribute>
                    <xsl:value-of select="$fieldValue"/>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="{$fieldName}">
                    <xsl:value-of select="$fieldValue"/>
                </xsl:element>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- Mapping for a descriptiveUnit: we create one Aggregation and one ProvidedCHO (inline inside the Aggregation) -->
    <xsl:template name="descriptiveUnitTemplate">
        <xsl:variable name="tokenized">
            <xsl:call-template name="getAggrID">
                <xsl:with-param name="input" select="../persistentID"/>
                <xsl:with-param name="lastInput" select="string('')"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="aggrID">
            <xsl:choose>
                <xsl:when test="$tokenized != ''">
                    <xsl:value-of select="$tokenized"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat('HA', '::', ../persistentID)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <ore:Aggregation rdf:about="{$aggrID}">
            <edm:aggregatedCHO rdf:resource="{../persistentID}"/>
            <!-- 
                Use views only if there are more resources associated to the descriptive unit. 
                E.g., several pages of the same book, when you have descriptive metadata only for the book but not for each single page.
            -->
            <xsl:if test="count(//digitalResource) &gt; 1">
                <xsl:for-each select="//digitalResource">
                    <edm:hasView rdf:resource="{./derivative2/@PID}"/>
                </xsl:for-each>
            </xsl:if>
            <edm:dataProvider>
                <xsl:value-of select="./isSuppliedBy"/>
            </edm:dataProvider>
            <edm:provider>HOPE - Heritage of the People&apos;s Europe</edm:provider>
            <edm:rights rdf:resource="{./rights[@label='europeana rights']}"/>
            <!-- 
                Often the landing page is the same as the persistent identifier. 
                We can't use the same URL for the aggregatedCHO and the landign page, hence we append '#1" to the landing page.
            -->
            <xsl:variable name="lPage" select="normalize-space(concat(./landingPage, '#1'))"/>

            <xsl:choose>
                <xsl:when test="count(//digitalResource) &gt;= 1">
                    <edm:isShownBy rdf:resource="{//digitalResource[1]/derivative2/@PID}"/>

                    <xsl:if test="$lPage != '#1'">
                        <edm:isShownAt rdf:resource="{$lPage}"/>
                    </xsl:if>
                    <xsl:choose>
                        <!-- 
                            edm:object is used for the generation of the thumbnails.
                            If we are dealing with a VIDEO or a SOUND, we can't pass the derivative2 file, because it contains the video or the audio file. 
                            An image that can be used for the thumbnails is instead the derivative3 file. 
                            For TEXT and IMAGE, we can pass the derivative2 file.
                        -->
                        <xsl:when test="normalize-space(./europeanaType) = 'VIDEO'">
                            <edm:object rdf:resource="{//digitalResource[1]/derivative3/@PID}"/>
                        </xsl:when>
                        <xsl:when test="normalize-space(./europeanaType) = 'SOUND'">
                            <edm:object rdf:resource="{//digitalResource[1]/derivative3/@PID}"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <edm:object rdf:resource="{//digitalResource[1]/derivative2/@PID}"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test="$lPage != '#1'">
                        <edm:isShownAt rdf:resource="{$lPage}"/>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </ore:Aggregation>
        <edm:ProvidedCHO rdf:about="{../persistentID}">
            <xsl:if test="starts-with(./isContainedBy, 'http:')">
                <dcterms:isPartOf rdf:resource="{./isContainedBy}"/>
            </xsl:if>
            <xsl:for-each select="./provenance">
                <dcterms:provenance>
                    <xsl:value-of select="."/>
                </dcterms:provenance>
            </xsl:for-each>
            <xsl:for-each select="./spatialCoverage">
                <xsl:if test="normalize-space(.) != ''">
                    <dcterms:spatial>
                        <xsl:value-of select="."/>
                    </dcterms:spatial>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./temporalCoverage">
                <xsl:if test="normalize-space(.) != ''">
                    <dcterms:temporal>
                        <xsl:value-of select="."/>
                    </dcterms:temporal>
                </xsl:if>
            </xsl:for-each>
            <!-- dcterms:tableOfContents -->
            <!-- Dimitra said to put digitalResource/transcription in dcterms:tableOfContents 
									of the providedCHO -->
            <xsl:for-each select="//digitalResource/transcription">
                <xsl:if test="normalize-space(.) != ''">
                    <dcterms:tableOfContents>
                        <xsl:value-of select="normalize-space(.)"/>
                    </dcterms:tableOfContents>
                </xsl:if>
            </xsl:for-each>

            <!-- domain specific properties - dcterms -->
            <xsl:apply-templates mode="dcTerms" select="./domain/*"/>

            <dc:identifier>
                <xsl:value-of select="../persistentID"/>
            </dc:identifier>
            <xsl:for-each select="./localIDCollectionItem">
                <xsl:if test="normalize-space(.) != ''">
                    <dc:identifier>
                        <xsl:value-of select="normalize-space(.)"/>
                    </dc:identifier>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./title[@label='title']">
                <xsl:if test="normalize-space(.) != ''">
                    <xsl:call-template name="langField">
                        <xsl:with-param name="fieldName" select="string('dc:title')"/>
                        <xsl:with-param name="fieldValue" select="."/>
                        <xsl:with-param name="language" select="./@language"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./creator">
                <xsl:if test="normalize-space(./value) != ''">
                    <dc:creator>
                        <xsl:value-of select="./value"/>
                    </dc:creator>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./contributor">
                <xsl:if test="normalize-space(./value) != ''">
                    <dc:contributor>
                        <xsl:value-of select="./value"/>
                    </dc:contributor>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./publisher">
                <xsl:if test="normalize-space(./value) != ''">
                    <dc:publisher>
                        <xsl:value-of select="./value"/>
                    </dc:publisher>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./description">
                <xsl:if test="normalize-space(.) != ''">
                    <xsl:call-template name="langField">
                        <xsl:with-param name="fieldName" select="string('dc:description')"/>
                        <xsl:with-param name="fieldValue" select="."/>
                        <xsl:with-param name="language" select="./@language"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./subject">
                <xsl:if test="normalize-space(.) != ''">
                    <dc:subject>
                        <xsl:value-of select="."/>
                    </dc:subject>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./associatedHopeTheme">
                <xsl:if test="normalize-space(.) != ''">
                    <dc:subject>
                        <xsl:value-of select="."/>
                    </dc:subject>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="./language[@normalised != '']">
                <dc:language>
                    <xsl:value-of select="./@normalised"/>
                </dc:language>
            </xsl:for-each>
            <xsl:for-each select="./rights[@label != 'europeana rights']">
                <dc:rights>
                    <xsl:value-of select="."/>
                </dc:rights>
            </xsl:for-each>
            <dc:relation>
                <xsl:value-of select="string('http://www.peoplesheritage.eu')"/>
            </dc:relation>
            <xsl:for-each select="./relation">
                <dc:relation>
                    <xsl:value-of select="."/>
                </dc:relation>
            </xsl:for-each>
            <dc:type>
                <xsl:value-of select=".//descriptionLevel/@normalised"/>
            </dc:type>
            <!--domain specific properties - no dcterms -->
            <xsl:apply-templates mode="duMode" select="./domain/*"/>
            <edm:type>
                <xsl:value-of select="./europeanaType"/>
            </edm:type>
            <!-- isNextInSequence: TO BE IMPLEMENTED.
                In HOPE one descritpive unit links to the next one. 
                In EDM, one ProvidedCHO links to the previous one. 
                Hence we can't just pass the information into EDM, we must calculate the inverse relationship before running this transformation. 
            -->
            <!-- <edm:isNextInSequence rdf:resource="TODO" /> -->
        </edm:ProvidedCHO>
    </xsl:template>

    <!-- helper templates to group europeana dcterms at the beginning of 
							provdedCHO as required by the schema -->
    <xsl:template match="dublinCoreUnit" mode="dcTerms">
        <xsl:for-each select="./extent">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:extent')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./medium">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:medium')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="archiveUnit" mode="dcTerms">
        <xsl:for-each select="../../title">
            <xsl:if test="./@label = 'parent title'">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:alternative')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./extent">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:extent')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./dimensions">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:extent>
                    <xsl:value-of select="."/>
                </dcterms:extent>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="../../date[@label='date of creation']">
            <xsl:if test="./@normalised != ''">
                <dcterms:created>
                    <xsl:value-of select="./@normalised"/>
                </dcterms:created>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="libraryUnit" mode="dcTerms">
        <xsl:for-each select="../../date[@label='date of publication']">
            <xsl:if test="./@normalised != ''">
                <dcterms:issued>
                    <xsl:value-of select="./@normalised"/>
                </dcterms:issued>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./generalMaterialDesignation">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:medium')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="../../title">
            <xsl:if
                test="./@label != 'title proper' and ./@label !='title' and normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:alternative')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="visualUnit" mode="dcTerms">
        <xsl:for-each select="../../date[@label='object production date']">
            <xsl:if test="normalize-space(./@normalised) != ''">
                <dcterms:created>
                    <xsl:value-of select="./@normalised"/>
                </dcterms:created>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./material">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:medium>
                    <xsl:value-of select="."/>
                </dcterms:medium>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./dimensions">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:extent>
                    <xsl:value-of select="normalize-space(.)"/>
                </dcterms:extent>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="audioVisualUnit" mode="dcTerms">
        <xsl:for-each select="./carrierType">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dcterms:medium')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./originalDuration">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:extent>
                    <xsl:value-of select="normalize-space(.)"/>
                </dcterms:extent>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./originalLenght">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:extent>
                    <xsl:value-of select="normalize-space(.)"/>
                </dcterms:extent>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./gauge">
            <xsl:if test="normalize-space(.) != ''">
                <dcterms:extent>
                    <xsl:value-of select="normalize-space(.)"/>
                </dcterms:extent>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    <!-- end of dcterms helper templates -->

    <!-- Template for generic (QDC-based) domain properties -->
    <xsl:template match="dublinCoreUnit" mode="duMode">
        <xsl:for-each select="../../date[@label='date']">
            <xsl:if test="./@normalised != ''">
                <dc:date>
                    <xsl:value-of select="./@normalised"/>
                </dc:date>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <!-- Template for archive domain properties -->
    <xsl:template match="archiveUnit" mode="duMode">
        <xsl:for-each select="./appearanceOfMaterial">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:description')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./genreOfFonds">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:type')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./physicalCharacteristics">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:description')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <!-- Template for library domain properties -->
    <xsl:template match="libraryUnit" mode="duMode">
        <xsl:for-each select="../../date[@label='date of printing or manufacture or engraving']">
            <xsl:if test="./@normalised != ''">
                <dc:date>
                    <xsl:value-of select="./@normalised"/>
                </dc:date>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./specificMaterialDesignation">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:type')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./otherPhysicalDetails">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:description')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="../../title">
            <xsl:if test="./@label = 'title proper'">
                <xsl:if test="normalize-space(.) != ''">
                    <xsl:call-template name="langField">
                        <xsl:with-param name="fieldName" select="string('dc:title')"/>
                        <xsl:with-param name="fieldValue" select="."/>
                        <xsl:with-param name="language" select="./@language"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <!-- Template for visual domain properties -->
    <xsl:template match="visualUnit" mode="duMode">
        <xsl:for-each select="./objectName">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:type')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./technicalAttribute">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:format')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./technique">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:format')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <!-- Template for audio/video domain properties -->
    <xsl:template match="audioVisualUnit" mode="duMode">
        <xsl:for-each select="./instantiationType">
            <xsl:if test="normalize-space(.) != ''">
                <xsl:call-template name="langField">
                    <xsl:with-param name="fieldName" select="string('dc:type')"/>
                    <xsl:with-param name="fieldValue" select="."/>
                    <xsl:with-param name="language" select="./@language"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./aspectRatio">
            <xsl:if test="normalize-space(.) != ''">
                <dc:format>
                    <xsl:value-of select="normalize-space(.)"/>
                </dc:format>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./colourSystem">
            <xsl:if test="normalize-space(.) != ''">
                <dc:format>
                    <xsl:value-of select="normalize-space(.)"/>
                </dc:format>
            </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="./soundSystem">
            <xsl:if test="normalize-space(.) != ''">
                <dc:format>
                    <xsl:value-of select="normalize-space(.)"/>
                </dc:format>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>


    <!-- 
        Template for DigitalResource mapping. One WebResource entity is created.
    -->
    <xsl:template name="digitalResourceTemplate">
        <edm:WebResource rdf:about="{./derivative2/@PID}">
            <edm:rights rdf:resource="{./rights/@normalised}"/>
            <!-- Dimitra said to put this in a dcterms:tableOfContents of the 
									providedCHO -->
            <!-- <xsl:if test="normalize-space(./transcription) != ''"> <dcterms:isFormatOf> 
									<xsl:value-of select="normalize-space(./transcription)" /> </dcterms:isFormatOf> 
									</xsl:if> -->
            <xsl:if test="./transcription/@PID != ''">
                <dcterms:isFormatOf>
                    <xsl:value-of select="./transcription/@PID"/>
                </dcterms:isFormatOf>
            </xsl:if>
            <!-- Not yet supported by EDM -->
            <!-- <dcterms:isFormatOf><xsl:value-of select="./derivative2/@PID"/></dcterms:isFormatOf> 
									<dcterms:isFormatOf><xsl:value-of select="./derivative3/@PID"/></dcterms:isFormatOf> 
									<xsl:if test="normalize-space(./transcription) != ''"> <dcterms:isFormatOf><xsl:value-of 
									select="normalize-space(./transcription)"/></dcterms:isFormatOf> </xsl:if> 
									<xsl:if test="./transcription/@PID != ''"> <dcterms:isFormatOf><xsl:value-of 
									select="./transcription/@PID"/></dcterms:isFormatOf> </xsl:if> <dc:format><xsl:value-of 
									select="./type"/></dc:format> <edm:isNextInSequence rdf:resource="TODO"/> -->
        </edm:WebResource>
    </xsl:template>
</xsl:stylesheet>
